@@ -140,6 +140,11 @@ extern "C"
         return new(std::nothrow) apg::pattern(lab, lab->semisolid(depth, flags), ppat->getrule());
     }
 
+    void* BitshiftPattern(void* pat, int shift) {
+        auto ppat = reinterpret_cast<apg::pattern*>(pat);
+        return new(std::nothrow) apg::pattern(ppat->bitshift(shift));
+    }
+
     void* ShiftPattern(void* pat, int x, int y, uint64_t exponent) {
         auto ppat = reinterpret_cast<apg::pattern*>(pat);
         return new(std::nothrow) apg::pattern(ppat->shift(x, y, exponent));
