@@ -925,6 +925,56 @@ namespace apg {
 
         }
 
+        hypernode<I> bitshift_recurse(hypernode<I> hnode, std::map<std::pair<I, uint32_t>, I> *memmap, int shift) {
+
+            if (shift == 0) { return hnode; }
+
+            if ((shift >= N) || (shift <= -N)) { return hypernode<I>(0, hnode.depth); }
+
+            if (hnode.index2 != 0) {
+                return bitshift_recurse(breach(hnode), memmap, shift);
+            }
+
+            auto it = memmap->find(std::make_pair(hnode.index, hnode.depth));
+
+            if (hnode.index == 0) {
+                return hypernode<I>(0, hnode.depth);
+            } else if (it != memmap->end()) {
+                return hypernode<I>(it->second, hnode.depth);
+            } else if (hnode.depth == 0) {
+                // Extract the pointer to the node:
+                kiventry<nicearray<uint64_t, 4*N>, I, J >* pptr = ind2ptr_leaf(hnode.index);
+                nicearray<uint64_t, 4*N> outleaf = {0ull};
+
+                int lbound = (shift <= 0) ? 0 : shift;
+                int ubound = (shift >= 0) ? N : (N + shift);
+
+                for (int j = lbound * 4; j < ubound * 4; j++) {
+                    outleaf.x[j] = pptr->key.x[j - 4*shift];
+                }
+
+                I res = make_leaf(outleaf);
+                memmap->emplace(std::make_pair(hnode.index, 0), res);
+                return hypernode<I>(res, 0);
+            } else {
+                // Extract the pointer to the node:
+                kiventry<nicearray<I, 4>, I, J >* pptr = ind2ptr_nonleaf(hnode.depth, hnode.index);
+
+                // Lazy evaluation:
+                hypernode<I> ytl = bitshift_recurse(hypernode<I>(pptr->key.x[0], hnode.depth - 1), memmap, shift);
+                hypernode<I> ytr = bitshift_recurse(hypernode<I>(pptr->key.x[1], hnode.depth - 1), memmap, shift);
+                hypernode<I> ybl = bitshift_recurse(hypernode<I>(pptr->key.x[2], hnode.depth - 1), memmap, shift);
+                hypernode<I> ybr = bitshift_recurse(hypernode<I>(pptr->key.x[3], hnode.depth - 1), memmap, shift);
+
+                // Assemble the transformed node:
+                nicearray<I, 4> cc = {ytl.index, ytr.index, ybl.index, ybr.index};
+                hypernode<I> xcc = make_nonleaf_hn(hnode.depth, cc);
+                memmap->emplace(std::make_pair(hnode.index, hnode.depth), xcc.index);
+                return xcc;
+            }
+
+        }
+
         hypernode<I> brand_recurse(hypernode<I> hnode, std::map<std::pair<I, uint32_t>, I> *memmap, bool disjunctive) {
 
             if (N == 1) { return hnode; }
