@@ -401,12 +401,18 @@ namespace apg {
         }
 
         virtual hypernode<I> brand_recurse(hypernode<I> hnode, std::map<std::pair<I, uint32_t>, I> *memmap, bool disjunctive) = 0;
+        virtual hypernode<I> bitshift_recurse(hypernode<I> hnode, std::map<std::pair<I, uint32_t>, I> *memmap, int shift) = 0;
 
         hypernode<I> brand_recurse(hypernode<I> hnode) {
             std::map<std::pair<I, uint32_t>, I> memmap;
             return brand_recurse(hnode, &memmap, false);
         }
 
+        hypernode<I> bitshift_recurse(hypernode<I> hnode, int shift) {
+            std::map<std::pair<I, uint32_t>, I> memmap;
+            return bitshift_recurse(hnode, &memmap, shift);
+        }
+
         hypernode<I> bror_recurse(hypernode<I> hnode) {
             std::map<std::pair<I, uint32_t>, I> memmap;
             return brand_recurse(hnode, &memmap, true);
