@@ -359,6 +359,10 @@ namespace apg {
             return basepattern<I>(lab, lab->pattern_match(hnode, hypernode<I>(0, 1), coerce(c1)), rulestring);
         }
 
+        basepattern<I> bitshift(int shift) {
+            return basepattern<I>(lab, lab->bitshift_recurse(hnode, shift), rulestring);
+        }
+
         basepattern<I> bror() {
             return basepattern<I>(lab, lab->bror_recurse(hnode), rulestring);
         }
@@ -730,6 +734,10 @@ namespace apg {
         // -----------------------------------------
     };
 
+    template<typename I>
+    basepattern<I> operator<<(basepattern<I> lhs, int amount) { return lhs.bitshift(amount); }
+    template<typename I>
+    basepattern<I> operator>>(basepattern<I> lhs, int amount) { return lhs.bitshift(-amount); }
     template<typename I>
     basepattern<I> operator+(basepattern<I> lhs, const basepattern<I> &rhs) { return lhs.disjunction(rhs); }
     template<typename I>
