@@ -2,6 +2,7 @@ import os
 from .lowlevel import *
 from numbers import Integral
 from .crt import chinese_remainder, large_primes
+from .samples import download_synthesis as dsynth
 
 
 def randfill(item, shape):
@@ -105,6 +106,11 @@ class Pattern(object):
         self.lifelib('BooleanPatternMutable', self.ptr, other.ptr, op)
         return self
 
+    def _bitshift(self, shift):
+
+        newptr = self.lifelib('BitshiftPattern', self.ptr, shift)
+        return Pattern(self.session, newptr, self.owner)
+
     def _boolean_immutable(self, other, op):
 
         newptr = self.lifelib('BooleanPatternImmutable', self.ptr, other.ptr, op)
@@ -146,6 +152,12 @@ class Pattern(object):
     def __mul__(self, other):
         return self._boolean_immutable(other, 4)
 
+    def __lshift__(self, other):
+        return self._bitshift(other)
+
+    def __rshift__(self, other):
+        return self._bitshift(-other)
+
     def convolve(self, other, exclusive=False):
         return self._boolean_immutable(other, (6 if exclusive else 5))
 
@@ -290,6 +302,10 @@ class Pattern(object):
         newptr = self.lifelib('GetOneCell', self.ptr)
         return Pattern(self.session, newptr, self.owner)
 
+    def layers(self):
+
+        return self.owner.deunify(self)
+
     def components(self, halo='ooo$ooo$ooo!'):
 
         ccs = []
@@ -691,6 +707,22 @@ class Pattern(object):
 
         return self.owner.download_samples(self.apgcode, self.getrule(), **kwargs)
 
+    def download_synthesis(self, tempfile='tempfile.rle', **kwargs):
+
+        rle = dsynth(self.apgcode, self.getrule(), tempfile=tempfile, **kwargs)
+
+        if rle is None:
+            synth = None
+        else:
+            synth = self.owner.load(tempfile)
+
+        try:
+            os.remove(tempfile)
+        except OSError:
+            pass
+
+        return synth
+
     @property
     def period(self):
 
