@@ -14,6 +14,23 @@ class TestGoL(unittest.TestCase):
         self.sess = lifelib.load_rules('b3s23')
         self.lt = self.sess.lifetree(memory=1000, n_layers=4)
 
+    def test_bitshift(self):
+
+        pd = self.lt.pattern('xp15_4r4z4r4')
+        self.assertEqual((pd << 3).wechsler, '0_0_0_4r4z4r4')
+        self.assertEqual((pd << 2).wechsler, '0_0_4r4z4r4')
+        self.assertEqual((pd << 1).wechsler, '0_4r4z4r4')
+
+        self.assertEqual(((pd << 2) >> 2), pd)
+
+        block = self.lt.pattern('xs4_33')
+        hwss = self.lt.pattern('xq4_27deee6')
+        mwss = self.lt.pattern('xq4_27dee6')
+
+        combined = self.lt.unify(block, pd, hwss, mwss)
+        self.assertEqual(combined.wechsler, '33_4r4z4r4_27deee6_27dee6')
+        self.assertEqual(combined.layers(), (block, pd, hwss, mwss))
+
     def test_ulimit(self):
 
         self.sess.lifelib.ensure_limit(10000, 1)
@@ -62,6 +79,10 @@ $3b3o3b2o3b2o3bo2bo7bo2bo12b3o$3bo2bo2b2o3b2o2bo3bo7bob2o12bo2bo$3bo
         periods = [s[10000][-1000:1000, -1000:1000].period for s in samples['C2_2']]
         self.assertEqual(periods[:20], [40]*20)
 
+        synth = pat.download_synthesis()
+        res = synth[1000]
+        self.assertEqual(res.period, 40)
+
     def test_hashsoup(self):
 
         x = self.lt.hashsoup("b3s23", "C1", "n_GcpqZ62YqD3310086454")
